Python Command-line Clients and API (deriva-py)
================================================

.. toctree::
   :maxdepth: 4
   :caption: API Guides

   README

.. toctree::
   :maxdepth: 10
   :caption: API Reference

   api/deriva

.. toctree::
   :maxdepth: 4
   :caption: Command Line Interfaces

   cli/deriva-acl-config
   cli/deriva-annotation-config
   cli/deriva-hatrac-cli
   cli/deriva-download-cli
   cli/deriva-sitemap-cli
   cli/deriva-backup-cli
   cli/deriva-restore-cli

